"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = usePrism;

var _react = _interopRequireDefault(require("react"));

var _loadModule = _interopRequireDefault(require("../utils/loadModule"));

var _getLanguages = _interopRequireDefault(require("../utils/getLanguages"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * A React effect hook that highlights code in a given element.

 * - Specify `{isContainer: true}` if your element is not the target, but instead contains target elements. (Uses `Prism.highlightAllUnder` instead of `Prism.highlightElement`)
 * - Specify `{useWorker: true}` to set the `async` flag in the prism highlighter. Only useful for large blocks of code.
 * - Check out the [prism documentation](https://prismjs.com/extending.html#api) for more details
 *
 * @param {Object} ref a React ref to the target element
 * @param {Object} options the options object
 * @param {String} [options.language = 'javascript'] name of the prism language to load
 * @param {String} [options.theme = 'okaidia'] name of the prism theme to load
 * @param {Boolean} [options.isContainer] whether the given element ref is a container
 * @param {Boolean} [options.useWorker] whether to use a web worker for highlighting
 * @param {Function} [options.callback] invoked when prism is done highlighting
 *
 */
function usePrism(ref, options) {
  _react.default.useEffect(function () {
    try {
      applyPrism(ref, options);
    } catch (error) {
      console.warn('[usePrism] failed', {
        error: error
      });
    }
  }, [ref.current || ref, options.language, options.theme, options.isContainer, options.useWorker, options.callback]);
}

function applyPrism(_x) {
  return _applyPrism.apply(this, arguments);
}

function _applyPrism() {
  _applyPrism = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(ref) {
    var _ref,
        _ref$language,
        language,
        _ref$theme,
        theme,
        _ref$isContainer,
        isContainer,
        _ref$useWorker,
        useWorker,
        _ref$callback,
        callback,
        isMounted,
        Prism,
        _iteratorNormalCompletion,
        _didIteratorError,
        _iteratorError,
        _iterator,
        _step,
        lang,
        _args = arguments;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref = _args.length > 1 && _args[1] !== undefined ? _args[1] : {}, _ref$language = _ref.language, language = _ref$language === void 0 ? 'javascript' : _ref$language, _ref$theme = _ref.theme, theme = _ref$theme === void 0 ? 'okaidia' : _ref$theme, _ref$isContainer = _ref.isContainer, isContainer = _ref$isContainer === void 0 ? false : _ref$isContainer, _ref$useWorker = _ref.useWorker, useWorker = _ref$useWorker === void 0 ? false : _ref$useWorker, _ref$callback = _ref.callback, callback = _ref$callback === void 0 ? undefined : _ref$callback;

            isMounted = function isMounted() {
              return !!(ref && ref.current);
            };

            _context.next = 4;
            return import(
            /* webpackChunkName: 'codeblock/prismjs' */
            'prismjs');

          case 4:
            Prism = _context.sent;

            if (!(isMounted() && theme)) {
              _context.next = 8;
              break;
            }

            _context.next = 8;
            return (0, _loadModule.default)('theme', theme);

          case 8:
            if (!(isMounted() && language)) {
              _context.next = 11;
              break;
            }

            _context.next = 11;
            return (0, _loadModule.default)('language', language);

          case 11:
            if (!(isMounted() && isContainer)) {
              _context.next = 39;
              break;
            }

            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 15;
            _iterator = (0, _getLanguages.default)(ref.current)[Symbol.iterator]();

          case 17:
            if (_iteratorNormalCompletion = (_step = _iterator.next()).done) {
              _context.next = 25;
              break;
            }

            lang = _step.value;

            if (!(isMounted() && lang)) {
              _context.next = 22;
              break;
            }

            _context.next = 22;
            return (0, _loadModule.default)('language', lang);

          case 22:
            _iteratorNormalCompletion = true;
            _context.next = 17;
            break;

          case 25:
            _context.next = 31;
            break;

          case 27:
            _context.prev = 27;
            _context.t0 = _context["catch"](15);
            _didIteratorError = true;
            _iteratorError = _context.t0;

          case 31:
            _context.prev = 31;
            _context.prev = 32;

            if (!_iteratorNormalCompletion && _iterator.return != null) {
              _iterator.return();
            }

          case 34:
            _context.prev = 34;

            if (!_didIteratorError) {
              _context.next = 37;
              break;
            }

            throw _iteratorError;

          case 37:
            return _context.finish(34);

          case 38:
            return _context.finish(31);

          case 39:
            if (isMounted()) {
              isContainer ? Prism.highlightAllUnder(ref.current, useWorker, callback) : Prism.highlightElement(ref.current, useWorker, callback);
            }

          case 40:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[15, 27, 31, 39], [32,, 34, 38]]);
  }));
  return _applyPrism.apply(this, arguments);
}