"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getLanguages;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var reg = /language-([a-z0-9\-]*)/;
/**
 * Returns a list of languages found as CSS classes inside a container element.
 *
 * Queries all child elements that have a `language-*` CSS classname, then iterates them
 * to return an array of unique language names that were found (the `*` values).
 *
 * @param {Element} target a DOM element
 * @return {Array} an array of languages found in children's classnames
 */

function getLanguages(target) {
  if (!target) {
    return [];
  }

  var elements = target.querySelectorAll('[class*="language-"]');
  return _toConsumableArray(elements).reduce(function (result, el) {
    var matches = el.className.match(reg);
    var language = matches && matches[1];

    if (language && !result.includes(language)) {
      result.push(language);
    }

    return result;
  }, []);
}