const reg = /language-([a-z0-9\-]*)/;

/**
 * Returns a list of languages found as CSS classes inside a container element.
 *
 * Queries all child elements that have a `language-*` CSS classname, then iterates them
 * to return an array of unique language names that were found (the `*` values).
 *
 * @param {Element} target a DOM element
 * @return {Array} an array of languages found in children's classnames
 */
export default function getLanguages(target) {
    if (!target) {
        return [];
    }
    const elements = target.querySelectorAll('[class*="language-"]');
    return [...elements].reduce((result, el) => {
        const matches = el.className.match(reg);
        const language = matches && matches[1];
        if (language && !result.includes(language)) {
            result.push(language);
        }
        return result;
    }, []);
}
